@@ -6,6 +6,7 @@ import schedule
 import time
 from itertools import groupby
 from operator import itemgetter
+import RPi.GPIO as GPIO
 
 HALF_POWER_HOURS = 8
 ZERO_POWER_HOURS = 6
@@ -128,8 +129,7 @@ class HeatControl:
         for hour in self.hour_prices:
             print(str(hour["Hour"]) + " " + str(hour["PriceNoTax"]))
 
-    def set_rasbperry_pi_gpio_pin(pin_number, state):
-        import RPi.GPIO as GPIO
+    def set_rasbperry_pi_gpio_pin(self, pin_number, state):
 
         GPIO.setmode(GPIO.BCM)
         GPIO.setup(pin_number, GPIO.OUT)
